cumulusci.tasks.release_notes.tests package
===========================================

Submodules
----------

cumulusci.tasks.release_notes.tests.test_generator module
---------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_generator
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release_notes.tests.test_parser module
------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_parser
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release_notes.tests.test_provider module
--------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_provider
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release_notes.tests.util_github_api module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.util_github_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.release_notes.tests
    :members:
    :undoc-members:
    :show-inheritance:
